@@ -12,16 +12,19 @@
 
 import subprocess
 from buildpan import setting
-import requests
+import requests, datetime
 
 info = setting.info
 
 # getting env variable
 get_sha = info["GET_SHA_URL"]
+fetch_log = info["FETCH_LOG_URL"]
 
 
-def prev_commit(path, repo_name):
+def prev_commit(path, repo_name, project_id, username):
     try:
+        curtime = datetime.datetime.now()
+
         # pooling to get sha for the previous commit
         response = requests.get(get_sha, repo_name)
         res=response.content
@@ -33,5 +36,8 @@ def prev_commit(path, repo_name):
         # restoring to previous commit
         subprocess.call(["git", "fetch", "origin", res], cwd=path)
         subprocess.call(["git", "checkout", "FETCH_HEAD"], cwd=path)
-    except:
-        print("error")
+
+        requests.post(fetch_log + "?" +'project_id='+project_id+'&repo_name='+repo_name+'&Time='+str(curtime)+'&user_name='+username+'&message=Pull'+'&status=success&operation=previous commit')
+
+    except Exception as e:
+        requests.post(fetch_log + "?" +'project_id='+project_id+'&repo_name='+repo_name+'&Time='+str(curtime)+'&user_name='+username+'&message=Pull = '+str(e)+'&status=failed&operation=previous commit')
