@@ -4,7 +4,7 @@
     Modified By: Kushagra A.
     Language: Python
     Date Created: 31-08-2021
-    Date Modified: 22-09-2021
+    Date Modified: 24-09-2021
     Description:
         ###############################################################
         ##      Calls deployer for workflow process                  ## 
@@ -12,6 +12,13 @@
  """
 
 from buildpan import yaml_reader, deployer
+from buildpan import setting
+import datetime, requests
+
+info = setting.info
+
+
+fetch_log = info["FETCH_LOG_URL"]
 
 def workflows(path, project_id, repo_name, username):
     
@@ -19,6 +26,7 @@ def workflows(path, project_id, repo_name, username):
         yaml_reader.yaml_reader(path)
         workflow = yaml_reader.yaml_reader.workflow
         jobs = yaml_reader.yaml_reader.jobs
+        curtime = datetime.datetime.now()
 
         success = False
         
@@ -38,4 +46,4 @@ def workflows(path, project_id, repo_name, username):
         return success
     
     except Exception as e:
-        print(e)
\ No newline at end of file
+        requests.post(fetch_log + "?" +'project_id='+project_id+'&repo_name='+repo_name+'&Time='+str(curtime)+'&user_name='+username+'&message=Exception: deployment = '+str(e)+'&status=failed&operation=deployment')
\ No newline at end of file
