@@ -19,6 +19,7 @@ from buildpan import setting, access_token
 info = setting.info
 
 fetch_log = info["FETCH_LOG_URL"]
+host = info["HOST"]
 
          
 def bitbucket(project_id, path, refresh_token, username, repo_name, provider):
@@ -36,7 +37,7 @@ def bitbucket(project_id, path, refresh_token, username, repo_name, provider):
         curtime = datetime.datetime.now()
         # creating a webhook on a particular repository
         hook_url = f"https://api.bitbucket.org/2.0/repositories/{username}/{repo_name}/hooks"
-        payload_url = "http://35.225.89.124/bit_webhook"
+        payload_url = f"http://{host}/bit_webhook"
 
         response3 = requests.get(hook_url, headers=header)
         data = response3.json()['values']
