@@ -19,7 +19,7 @@ from buildpan import find_path
 @click.command()
 def stop_all():
     '''
-    For deleting all repository information
+     For stop CI-CD operation
     \f
     
    
@@ -30,7 +30,7 @@ def stop_all():
 
     if os.path.exists(file_path + "/info.txt"):
         os.remove(file_path + "/info.txt")
-        print("File Deleted!")
+        print("CI-CD operation stopped \n Run:- buildpan init to intiate CICD operation")
     
     else:
-        print("File doesn't exists!")
\ No newline at end of file
+        print("No CI-CD operation running \n Run:- buildpan init to intiate CICD operation")
\ No newline at end of file
